==> react-atom-panel-1.6.0.tgz: package/lib/ImagePanel.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { COLORS, ALPHA } from './constants';
var HORIZONTAL_ALIGNMENTS = {
  LEFT: 'left',
  CENTER: 'center',
  RIGHT: 'right'
};
var VERTICAL_ALIGNMENTS = {
  TOP: 'top',
  CENTER: 'center',
  BOTTOM: 'bottom'
};
var DEFAULT_ALPHA = 'CONTRAST';
var DEFAULT_COLOR = 'ACCENT';

var getClassNames = function getClassNames(_ref) {
  var verticalAlign = _ref.verticalAlign,
      horizontalAlign = _ref.horizontalAlign,
      resized = _ref.resized,
      overlayColor = _ref.overlayColor,
      overlayAlpha = _ref.overlayAlpha,
      color = _ref.color;
  var BASE_CLASS = 'sui-atom-panel';
  var IMAGE_PANEL_CLASS = BASE_CLASS + "-image";
  var overlayAlphaValue = ALPHA[overlayAlpha] || DEFAULT_ALPHA;
  var overlayColorValue = COLORS[overlayColor] || DEFAULT_COLOR;
  return cx(IMAGE_PANEL_CLASS + "--vertical-" + verticalAlign, IMAGE_PANEL_CLASS + "--horizontal-" + horizontalAlign, overlayColor && BASE_CLASS + "--" + overlayColorValue + "-overlay-" + overlayAlphaValue, BASE_CLASS + "-color--" + color, resized && IMAGE_PANEL_CLASS + "--resized");
};

var getStyles = function getStyles(_ref2) {
  var src = _ref2.src;
  var url = "url(" + src + ")";
  return {
    backgroundImage: url
  };
};

var ImagePanel = function ImagePanel(_ref3) {
  var children = _ref3.children,
      props = _objectWithoutPropertiesLoose(_ref3, ["children"]);

  return /*#__PURE__*/React.createElement("div", {
    className: getClassNames(props),
    style: getStyles(props)
  }, children);
};

ImagePanel.displayName = 'ImagePanel';
ImagePanel.defaultProps = {
  overlayAlpha: DEFAULT_ALPHA,
  color: COLORS.DEFAULT
};
export default ImagePanel;
export { HORIZONTAL_ALIGNMENTS, VERTICAL_ALIGNMENTS };

==> react-atom-panel-1.8.0.tgz: package/lib/ImagePanel.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { COLORS, ALPHA, BORDER_RADIUS } from './constants';
var HORIZONTAL_ALIGNMENTS = {
  LEFT: 'left',
  CENTER: 'center',
  RIGHT: 'right'
};
var VERTICAL_ALIGNMENTS = {
  TOP: 'top',
  CENTER: 'center',
  BOTTOM: 'bottom'
};
var DEFAULT_ALPHA = 'CONTRAST';
var DEFAULT_COLOR = 'ACCENT';

var getClassNames = function getClassNames(_ref) {
  var verticalAlign = _ref.verticalAlign,
      horizontalAlign = _ref.horizontalAlign,
      resized = _ref.resized,
      overlayColor = _ref.overlayColor,
      overlayAlpha = _ref.overlayAlpha,
      color = _ref.color,
      rounded = _ref.rounded;
  var BASE_CLASS = 'sui-atom-panel';
  var IMAGE_PANEL_CLASS = BASE_CLASS + "-image";
  var overlayAlphaValue = ALPHA[overlayAlpha] || DEFAULT_ALPHA;
  var overlayColorValue = COLORS[overlayColor] || DEFAULT_COLOR;
  return cx(BASE_CLASS, rounded !== BORDER_RADIUS.NONE && BASE_CLASS + "--rounded-" + rounded, IMAGE_PANEL_CLASS + "--vertical-" + verticalAlign, IMAGE_PANEL_CLASS + "--horizontal-" + horizontalAlign, overlayColor && BASE_CLASS + "--" + overlayColorValue + "-overlay-" + overlayAlphaValue, BASE_CLASS + "-color--" + color, resized && IMAGE_PANEL_CLASS + "--resized");
};

var getStyles = function getStyles(_ref2) {
  var src = _ref2.src;
  var url = "url(" + src + ")";
  return {
    backgroundImage: url
  };
};

var ImagePanel = function ImagePanel(_ref3) {
  var children = _ref3.children,
      props = _objectWithoutPropertiesLoose(_ref3, ["children"]);

  return /*#__PURE__*/React.createElement("div", {
    className: getClassNames(props),
    style: getStyles(props)
  }, children);
};

ImagePanel.displayName = 'ImagePanel';
ImagePanel.defaultProps = {
  overlayAlpha: DEFAULT_ALPHA,
  color: COLORS.DEFAULT,
  rounded: BORDER_RADIUS.NONE
};
export default ImagePanel;
export { HORIZONTAL_ALIGNMENTS, VERTICAL_ALIGNMENTS };
